#
# spec file for package duperemove
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tar_version 0.10.beta4
%define samename btrfs-extent-same
Name:           duperemove
Version:        0.10.beta4
Release:        6.4
Summary:        Software to find duplicate extents in files and remove them
License:        GPL-2.0
Group:          System/Filesystems
Url:            https://github.com/markfasheh/duperemove
Source:         https://github.com/markfasheh/%{name}/archive/v%{tar_version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  sqlite3-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Duperemove finds duplicate extents in files and prints them to the
console. It also has the option to remove duplicates on those file
systems which support the btrfs-extent-same ioctl.

%package -n %{samename}
Summary:        Debug/Test tool to exercise the btrfs out-of-band deduplication ioctl
Group:          System/Filesystems

%description -n %{samename}
Debug/Test tool to exercise a btrfs ioctl for deduplicating file regions.

%prep
%setup -q -n %{name}-%{tar_version}
# Set the destdir / prefix
sed -i \
    -e 's:DESTDIR =:DESTDIR ?=:g' \
    -e 's:%{_prefix}/local:/usr:g' \
    Makefile

%build
%if %suse_version <= 1200
make %{?_smp_mflags} CFLAGS="%{optflags} -DNO_BTRFS_HEADER"
%else
make %{?_smp_mflags} CFLAGS="%{optflags}"
%endif

%install
%make_install

%files -n %{samename}
%defattr(-, root, root)
%{_sbindir}/%{samename}
%{_mandir}/man?/%{samename}.8.*

%files
%defattr(-, root, root)
%doc LICENSE README.md FAQ.md
%{_sbindir}/duperemove
%{_sbindir}/hashstats
%{_sbindir}/show-shared-extents
%{_mandir}/man?/%{name}.8.*
%{_mandir}/man?/hashstats.8.*
%{_mandir}/man?/show-shared-extents.8.*

%changelog
* Thu Jul 16 2015 mfasheh@suse.com
- Update to duperemove v0.10.beta4
  - Better memory usage with hashstats utility
* Fri Jul 10 2015 mfasheh@suse.com
- Update to duperemove v0.10.beta3
  - fixes many crashes in the dedupe stage
  - fixed an issue with our alignment function which would throw dedupe into
    a loop
  - improvements to output formatting
  - better logic when throwing out already-deduped extents won't give as
    many false positives
* Tue Jun 30 2015 mfasheh@suse.com
- Update to duperemove v0.10.beta2
  - multi-threaded dedupe stage (increased performance)
  - hashfile mode for drastically improved memory consumption
  - now uses murmur3 hash internally for improved cpu usage
  - can now take input from 'fdupes'
* Mon Apr  6 2015 mfasheh@suse.com
- Update with correct tarball (last one didn't have version number bump)
* Mon Apr  6 2015 mfasheh@suse.com
- Update to duperemove v0.09.3
  - Fix hang during file scan phase (bsc#926098)
- References: bsc#926098
* Thu Mar 26 2015 mfasheh@suse.com
- Update to duperemove v0.09.2
  - Now compiles on SLE11 targets
  - Fallback to stat on filesystems that don't report file type from
    readdir
  - Don't assert on failed open during dedupe
- References: bsc#923277 bsc#924577
* Thu Mar 19 2015 mfasheh@suse.com
- Update to duperemove v0.09.1
  - Fallback to stat on filesystems that don't report file type from
    readdir
* Thu Jan 29 2015 mfasheh@suse.com
- Update to duperemove v0.09
  - start with first node in free_compare_tree
  - fix small typos in duperemove man page
  - add test_progs variable in Makefile
- References: bsc#915354 FATE#318171
- Removed patch: do-not-install-test-binary.patch
* Tue Jan 20 2015 tchvatal@suse.com
- Cleanup a bit with spec-cleaner and fix few tiny issues
- Use install phase from upstream Makefile
- Move csum-test to test progs to prevent its install:
  * do-not-install-test-binary.patch
* Tue Dec  9 2014 mfasheh@suse.com
- Update to duperemove v0.09.beta5
  - Documentation updates
  - FAQ and README are more relevant now
  - added man pages for show-shared-extents and hashstats programs
  - updated duperemove man page, and duperemove usage() function
  - Have show-shared-extents take a file list as arguments.
  - Change default of --lookup-extents option back to 'no'
  - Write hash type into hashfile header, check against what hash we were
    compiled with.
* Mon Nov 17 2014 mfasheh@suse.com
- Update to duperemove v0.09.beta3
  - Fix leak of directory fd during file scan
  - Fix EMFILES (too many file descriptors) error during dedupe
  - Fix corner case with dedupe leaving a file open and not-queued
  - Support '-x' (one file system) option
  - Add option to turn off extent lookup during csum phase
  - Useful if running against snapshotted volumes
  - show-shared-extents program to help users examine file state before or
    after dedupe.
* Mon Nov 10 2014 schwab@suse.de
- Build with %%optflags
* Fri Oct 31 2014 mfasheh@suse.com
- Update to duperemove v0.09.beta2
  - fix memory leak
  - fix hardlink detection on btrfs
  - print file number status during csum phase
  - print a status bar during extent seearch
  - several bugfixes and performance improvements to extent search
- Removed patch: 001-fix-build.patch
* Sat Sep 27 2014 mfasheh@suse.com
- update to duperemove v0.09.beta1
  - parallel checksum calculation
  - performance improvements
  - allow to store the hash tree to a file
  - hashstats: new utility to analyze hash files
  - add --version option
  - build: add install target
  - documentatin updates
- Added patch: 001-fix-build.patch
* Sun Apr 20 2014 mfasheh@suse.com
- update to duperemove v0.08
  - fixes many bugs
  - a few more usability improvements
  - adds fiemap support to better estimate space savings
* Fri Apr 11 2014 mfasheh@suse.com
- update to duperemove v0.07
- fix usability of command line arguments
- large documentation update
* Fri Apr 11 2014 mfasheh@suse.com
- update to duperemove v0.06. This adds several fixes and features:
  - fixes bnc#871804 (duperemove not looping on entire range)
- also includes important usability fixes
- updates hashing library to libgcrypt to reflect upstream
* Wed Mar 12 2014 mfasheh@suse.com
- add duperemove rpm
- add new tarball with manpages for all binaries
* Wed Mar 12 2014 mfasheh@suse.com
- Initial creation of rpm and rpm changelog
